@@ -15,8 +15,8 @@ DBItest::make_context(
 
     # bad tests
     "list_objects_features",
-    if (.Platform$r_arch == "i386") "append_roundtrip_timestamp",
-    if (.Platform$r_arch == "i386") "roundtrip_timestamp",
+    "append_roundtrip_timestamp",
+    "roundtrip_timestamp",
 
     NULL
   )
